=============================
Module - validations_read_ini
=============================


This module provides for the following ansible plugin:

    * validations_read_ini


.. ansibleautoplugin::
   :module: validations_common/library/validations_read_ini.py
   :documentation: true
   :examples: true
